@@ -121,6 +121,7 @@ class Position:
     mode: Optional[PositionMode] = None
     bounding_rect: Optional[BoundingRect] = None
     text_starts_with: Optional[str] = None
+    text_pattern: Optional[str] = None
     name: Optional[str] = None
 
     @staticmethod
@@ -185,21 +186,6 @@ class Position:
         """Returns the Y coordinate of this position."""
         return self.bounding_rect.get_y() if self.bounding_rect else None
 
-    def copy(self) -> 'Position':
-        """Creates a copy of this position."""
-        # Create deep copy of bounding_rect if it exists
-        bounding_rect_copy = None
-        if self.bounding_rect:
-            bounding_rect_copy = BoundingRect(
-                self.bounding_rect.x,
-                self.bounding_rect.y,
-                self.bounding_rect.width,
-                self.bounding_rect.height
-            )
-
-        pos = Position(self.page_index, self.shape, self.mode, bounding_rect_copy, self.text_starts_with)
-        return pos
-
 
 @dataclass
 class ObjectRef:
@@ -325,7 +311,8 @@ class FindRequest:
         """Convert Position to dictionary for JSON serialization."""
         result = {
             "pageIndex": position.page_index,
-            "textStartsWith": position.text_starts_with
+            "textStartsWith": position.text_starts_with,
+            "textPattern": position.text_pattern
         }
         if position.name:
             result["name"] = position.name
@@ -419,7 +406,8 @@ class AddRequest:
                     text_element = {
                         "text": line,
                         "font": {"name": obj.font.name, "size": obj.font.size} if obj.font else None,
-                        "color": {"r": obj.color.r, "g": obj.color.g, "b": obj.color.b} if obj.color else None,
+                        "color": {"red": obj.color.r, "green": obj.color.g, "blue": obj.color.b,
+                                  "alpha": obj.color.a} if obj.color else None,
                         "position": FindRequest._position_to_dict(obj.position) if obj.position else None
                     }
                     text_line = {
@@ -427,7 +415,8 @@ class AddRequest:
                     }
                     # TextLine has color and position
                     if obj.color:
-                        text_line["color"] = {"r": obj.color.r, "g": obj.color.g, "b": obj.color.b}
+                        text_line["color"] = {"red": obj.color.r, "green": obj.color.g, "blue": obj.color.b,
+                                              "alpha": obj.color.a}
                     if obj.position:
                         text_line["position"] = FindRequest._position_to_dict(obj.position)
                     lines.append(text_line)
@@ -515,3 +504,46 @@ class FormFieldRef(ObjectRef):
     def get_value(self) -> Optional[str]:
         """Get the form field value."""
         return self.value
+
+
+class TextObjectRef(ObjectRef):
+    """
+    Represents a text object reference with additional text-specific properties.
+    Extends ObjectRef to include text content, font information, and hierarchical structure.
+    """
+
+    def __init__(self, internal_id: str, position: Position, object_type: ObjectType,
+                 text: Optional[str] = None, font_name: Optional[str] = None,
+                 font_size: Optional[float] = None, line_spacings: Optional[List[float]] = None,
+                 color: Optional[Color] = None):
+        super().__init__(internal_id, position, object_type)
+        self.text = text
+        self.font_name = font_name
+        self.font_size = font_size
+        self.line_spacings = line_spacings
+        self.color = color
+        self.children: List['TextObjectRef'] = []
+
+    def get_text(self) -> Optional[str]:
+        """Get the text content."""
+        return self.text
+
+    def get_font_name(self) -> Optional[str]:
+        """Get the font name."""
+        return self.font_name
+
+    def get_font_size(self) -> Optional[float]:
+        """Get the font size."""
+        return self.font_size
+
+    def get_line_spacings(self) -> Optional[List[float]]:
+        """Get the line spacings."""
+        return self.line_spacings
+
+    def get_color(self) -> Optional[Color]:
+        """Get the color."""
+        return self.color
+
+    def get_children(self) -> List['TextObjectRef']:
+        """Get the child text objects."""
+        return self.children
